summaryrefslogtreecommitdiffstats
path: root/kmymoney2/dialogs/ksplittransactiondlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/dialogs/ksplittransactiondlg.h')
-rw-r--r--kmymoney2/dialogs/ksplittransactiondlg.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kmymoney2/dialogs/ksplittransactiondlg.h b/kmymoney2/dialogs/ksplittransactiondlg.h
index 76261bd..1a292d2 100644
--- a/kmymoney2/dialogs/ksplittransactiondlg.h
+++ b/kmymoney2/dialogs/ksplittransactiondlg.h
@@ -61,7 +61,7 @@ public:
const bool deposit,
const MyMoneyMoney& calculatedValue,
const TQMap<TQString, MyMoneyMoney>& priceInfo,
- TQWidget* tqparent = 0, const char* name = 0);
+ TQWidget* parent = 0, const char* name = 0);
virtual ~KSplitTransactionDlg();
@@ -116,13 +116,13 @@ protected slots:
signals:
/**
* This signal is sent out, when a new category needs to be created
* Depending on the setting of either a payment or deposit, the tqparent
* account will be preset to Expense or Income.
*
* @param account reference to account info. Will be filled by called slot
* @param tqparent reference to tqparent account
*/
- void createCategory(MyMoneyAccount& account, const MyMoneyAccount& tqparent);
+ void createCategory(MyMoneyAccount& account, const MyMoneyAccount& parent);
/**
* Signal is emitted, if any of the widgets enters (@a state equals @a true)
@@ -116,13 +116,13 @@ protected slots:
/**
* This signal is sent out, when a new category needs to be created
- * Depending on the setting of either a payment or deposit, the tqparent
+ * Depending on the setting of either a payment or deposit, the parent
* account will be preset to Expense or Income.
*
@@ -116,13 +116,13 @@ protected slots:
*
* @param account reference to account info. Will be filled by called slot
- * @param tqparent reference to tqparent account
+ * @param parent reference to parent account
*/